ChatDBFireStore class

Constructors

ChatDBFireStore()

Properties

friendList ↔ List?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAllFriendList(dynamic friendId, dynamic currentUserId) → Future<List?>
getFriendList(dynamic userId) → Future<List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setChatLastSeen(dynamic currentUserId, dynamic stCollection, dynamic chatId, bool isChat) → void
setChatWith(String? id, String? peerId) → void
setUserLastSeen(User? logInUser) → dynamic
streamChatDataList(dynamic stCollection, dynamic groupChatId) → Stream<QuerySnapshot<Object?>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

checkUserExists(User logInUser) → Future<void>
getDocName() → String
makeUserOnline(User logInUser) → Future<void>
saveNewUser(User logInUser) → dynamic
streamChatData() → dynamic