ChatData class

Constructors

ChatData()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getImage(int index) → Future<PickedFile?>
Pick Image from Camera or gallery index 0->Gallery 1->Camera
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
uploadFile(PickedFile orFile) → Future<String>
Upload PickedFile to Cloud Storage and get file url

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

appName ↔ String
getter/setter pair

Static Methods

authUser(BuildContext context) → void
authUsersGoogle(BuildContext context) → Future<bool>
checkUserLoggedin(BuildContext context) → Future<bool>
checkUserLogin(BuildContext context) → dynamic
getGroupChatID(String? logInUserId, String? peerId) → String
handleSignOut(BuildContext context) → Future<Null>
init(String applicationName, BuildContext context) → dynamic
isLastMessageLeft(dynamic listMessage, String id, int index) → bool
isLastMessageRight(dynamic listMessage, String id, int index) → bool
isSignedIn() → Future<bool>
openDialog(BuildContext context) → Future<Null>
startTime(BuildContext context) → dynamic