ChatWidget class

Constructors

ChatWidget()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

chatImage(BuildContext context, String id, dynamic listMessage, String? chatContent, int index, bool logUserMsg) → Widget
chatText(String chatContent, String id, dynamic listMessage, int index, bool logUserMsg) → Widget
getAppBar(String text) → PreferredSizeWidget?
getFriendList() → dynamic
userListbuildItem(BuildContext context, String currentUserId, DocumentSnapshot<Object?> document) → Widget
widgetChatBuildItem(BuildContext context, dynamic listMessage, String id, int index, DocumentSnapshot<Object?> document, String? peerAvatar) → Widget
widgetChatBuildListMessage(dynamic groupChatId, dynamic listMessage, dynamic currentUserId, dynamic peerAvatar, dynamic listScrollController, dynamic stCollection) → Widget
widgetFullPhoto(BuildContext context, String url) → Widget
widgetLoginScreen(BuildContext context) → Widget
widgetShowImages(String imageUrl, double imageSize) → Widget
widgetShowText(String text, dynamic textSize, dynamic textColor) → Widget
widgetWelcomeScreen(BuildContext context) → Widget